@@ -1,6 +1,6 @@
-/* $Id: gucharmap-mini-fontsel.c,v 1.6 2003/10/02 21:20:54 nlevitt Exp $ */
+/* $Id: gucharmap-mini-fontsel.c,v 1.11 2004/01/31 22:58:47 nlevitt Exp $ */
 /*
- * Copyright (c) 2003 Noah Levitt
+ * Copyright (c) 2004 Noah Levitt
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -17,17 +17,13 @@
  * 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  */
 
-#if HAVE_CONFIG_H
-# include "config.h"
-#endif
-
+#include "config.h"
 #include <gtk/gtk.h>
 #include <stdlib.h>
 #include <string.h>
-#include <gucharmap/gucharmap-mini-fontsel.h>
-#include "gucharmap_intl.h"
-#include "gucharmap_marshal.h"
-
+#include "gucharmap-mini-fontsel.h"
+#include "gucharmap-intl.h"
+#include "gucharmap-marshal.h"
 
 enum
 {
@@ -149,7 +145,7 @@ mini_font_selection_finalize (GObject *object)
 }
 
 
-void
+static void
 gucharmap_mini_font_selection_class_init (GucharmapMiniFontSelectionClass *clazz)
 {
   clazz->changed = NULL;
@@ -191,18 +187,17 @@ italic_toggled (GtkToggleButton *toggle,
 }
 
 
-void
+static void
 gucharmap_mini_font_selection_init (GucharmapMiniFontSelection *fontsel)
 {
   AtkObject *accessib;
 
   gtk_widget_ensure_style (GTK_WIDGET (fontsel));
-  fontsel->font_desc = pango_font_description_copy (
-          GTK_WIDGET (fontsel)->style->font_desc);
+  fontsel->font_desc = pango_font_description_copy (GTK_WIDGET (fontsel)->style->font_desc);
+  fontsel->default_size = pango_font_description_get_size (fontsel->font_desc);
 
-  fontsel->size_adj = gtk_adjustment_new (
-          pango_font_description_get_size (fontsel->font_desc) / PANGO_SCALE, 
-          MIN_FONT_SIZE, MAX_FONT_SIZE, 1, 9, 0);
+  fontsel->size_adj = gtk_adjustment_new (pango_font_description_get_size (fontsel->font_desc) / PANGO_SCALE, 
+                                          MIN_FONT_SIZE, MAX_FONT_SIZE, 1, 9, 0);
 
   accessib = gtk_widget_get_accessible (GTK_WIDGET (fontsel));
   atk_object_set_name (accessib, _("Font"));
@@ -216,12 +211,14 @@ gucharmap_mini_font_selection_init (GucharmapMiniFontSelection *fontsel)
   gtk_editable_set_editable (GTK_EDITABLE (GTK_COMBO (fontsel->family)->entry),
                              FALSE);
 
-  fontsel->bold = gtk_toggle_button_new_with_mnemonic (_("_Bold"));
+  fontsel->bold = gtk_toggle_button_new_with_mnemonic (GTK_STOCK_BOLD);
+  gtk_button_set_use_stock (GTK_BUTTON (fontsel->bold), TRUE);
   gtk_widget_show (fontsel->bold);
   g_signal_connect (fontsel->bold, "toggled",
                     G_CALLBACK (bold_toggled), fontsel);
 
-  fontsel->italic = gtk_toggle_button_new_with_mnemonic (_("_Italic"));
+  fontsel->italic = gtk_toggle_button_new_with_mnemonic (GTK_STOCK_ITALIC);
+  gtk_button_set_use_stock (GTK_BUTTON (fontsel->italic), TRUE);
   gtk_widget_show (fontsel->italic);
   g_signal_connect (fontsel->italic, "toggled",
                     G_CALLBACK (italic_toggled), fontsel);
@@ -342,4 +339,17 @@ gucharmap_mini_font_selection_set_font_size (GucharmapMiniFontSelection *fontsel
   set_size (fontsel, size);
 }
 
+/* size in points */
+void
+gucharmap_mini_font_selection_set_default_font_size (GucharmapMiniFontSelection *fontsel, 
+                                                     gint                        size)
+{
+  fontsel->default_size = size;
+}
 
+/* size in points */
+void
+gucharmap_mini_font_selection_reset_font_size (GucharmapMiniFontSelection *fontsel)
+{
+  gucharmap_mini_font_selection_set_font_size (fontsel, fontsel->default_size);
+}
